"""RollingBearingOrder"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.modal_analysis.gears import _1857

_ROLLING_BEARING_ORDER = python_net_import(
    "SMT.MastaAPI.Utility.ModalAnalysis.Gears", "RollingBearingOrder"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="RollingBearingOrder")
    CastSelf = TypeVar(
        "CastSelf", bound="RollingBearingOrder._Cast_RollingBearingOrder"
    )


__docformat__ = "restructuredtext en"
__all__ = ("RollingBearingOrder",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RollingBearingOrder:
    """Special nested class for casting RollingBearingOrder to subclasses."""

    __parent__: "RollingBearingOrder"

    @property
    def order_for_te(self: "CastSelf") -> "_1857.OrderForTE":
        return self.__parent__._cast(_1857.OrderForTE)

    @property
    def rolling_bearing_order(self: "CastSelf") -> "RollingBearingOrder":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class RollingBearingOrder(_1857.OrderForTE):
    """RollingBearingOrder

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROLLING_BEARING_ORDER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_RollingBearingOrder":
        """Cast to another type.

        Returns:
            _Cast_RollingBearingOrder
        """
        return _Cast_RollingBearingOrder(self)
