"""VoltagePerAngularVelocity"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_VOLTAGE_PER_ANGULAR_VELOCITY = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements",
    "VoltagePerAngularVelocity",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="VoltagePerAngularVelocity")
    CastSelf = TypeVar(
        "CastSelf", bound="VoltagePerAngularVelocity._Cast_VoltagePerAngularVelocity"
    )


__docformat__ = "restructuredtext en"
__all__ = ("VoltagePerAngularVelocity",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_VoltagePerAngularVelocity:
    """Special nested class for casting VoltagePerAngularVelocity to subclasses."""

    __parent__: "VoltagePerAngularVelocity"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def voltage_per_angular_velocity(self: "CastSelf") -> "VoltagePerAngularVelocity":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class VoltagePerAngularVelocity(_1657.MeasurementBase):
    """VoltagePerAngularVelocity

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VOLTAGE_PER_ANGULAR_VELOCITY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_VoltagePerAngularVelocity":
        """Cast to another type.

        Returns:
            _Cast_VoltagePerAngularVelocity
        """
        return _Cast_VoltagePerAngularVelocity(self)
